nghxrg
=================

.. currentmodule:: pynrc.simul.nghxrg

.. autoclass:: pynrc.simul.nghxrg.HXRGNoise
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~pynrc.simul.nghxrg.HXRGNoise.message
      ~pynrc.simul.nghxrg.HXRGNoise.mknoise
      ~pynrc.simul.nghxrg.HXRGNoise.pink_noise
      ~pynrc.simul.nghxrg.HXRGNoise.white_noise

   .. rubric:: Methods Documentation

   .. automethod:: message
   .. automethod:: mknoise
   .. automethod:: pink_noise
   .. automethod:: white_noise
